__VERSION__ = '0.8.8'

UNIQUE_NAME_KEY = 'unique_name'
ACTION_KEY = 'action'
GLUE_TYPE_KEY = 'glue_type'

# Fields
ALL_DUNDER_KEY = '__all__'
NONE_DUNDER_KEY = '__none__'

# Context
VERSION_CONTEXT_NAME = 'DJANGO_GLUE_VERSION'
KEEP_LIVE_INTERVAL_TIME_MILLISECONDS_CONTEXT_NAME = 'DJANGO_GLUE_KEEP_LIVE_INTERVAL_TIME_MILLISECONDS'
SESSION_DATA_CONTEXT_NAME = 'DJANGO_GLUE_SESSION_DATA'

# Url
URL_APP_NAME = 'django_glue'
HANDLER_URL_NAME = 'handler'
KEEP_LIVE_HANDLER_URL_NAME = 'keep_live_handler'
SESSION_DATA_URL_NAME = 'session_data'
